@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2024 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -72,7 +72,7 @@ use base qw(DBIx::SearchBuilder RT::Base);
 $DBIx::SearchBuilder::PREFER_BIND = 1 unless defined $ENV{SB_PREFER_BIND};
 
 use RT::Base;
-use DBIx::SearchBuilder "1.40";
+use DBIx::SearchBuilder;
 
 use Scalar::Util qw/blessed/;
 
@@ -557,6 +557,7 @@ sub _LimitCustomField {
         if (   $args{'FIELD'} eq 'Content'
             && blessed $cf
             && $cf->IsNumeric
+            && $args{'OPERATOR'} !~ m/LIKE/i
             && ( !$args{QUOTEVALUE} || Scalar::Util::looks_like_number($args{'VALUE'}) ) )
         {
             $args{QUOTEVALUE} = 0;
